"""
botway.py

Python client package for Botway.
"""

__author__ = 'abdfnx'
__license__ = 'MIT'
__copyright__ = 'Copyright (c) 2022-now Abdfn'
__version__ = '0.0.5'

import yaml
import json
from os import path
from pathlib import Path

botwayStream = open(path.join(Path().home(), '.botway', 'botway.json'), 'r')
botwayConfigData = json.load(botwayStream)

botStream = open('.botway.yaml', 'r')
botConfigData = yaml.load(botStream, Loader=yaml.FullLoader)

def find(d, i):
    if i in d:
        yield d[i]

    for k, v in d.items():
        if isinstance(v, dict):
            for i in find(v, i):
                yield i

def getBotInfo(value):
    for val in find(botConfigData, 'bot'):
        return val[value]

if getBotInfo('lang') != 'python':
    raise RuntimeError('ERROR: Botway is not running in Python')

def GetToken():
    for val in find(botwayConfigData, 'botway'):
        return val['bots'][getBotInfo('name')]['bot_token']

def GetAppId():
    if getBotInfo('type') == 'slack':
        for val in find(botwayConfigData, 'botway'):
            return val['bots'][getBotInfo('name')]['bot_app_token']
    else:
        for val in find(botwayConfigData, 'botway'):
            return val['bots'][getBotInfo('name')]['bot_app_id']

def GetGuildId(serverName):
    if getBotInfo('type') != 'discord':
        raise RuntimeError('ERROR: This function/feature is only working with discord bots.')
    else:
        for val in find(botwayConfigData, 'botway'):
            return val['bots'][getBotInfo('name')]['guilds'][serverName]['server_id']

def GetSigningSecret():
    if getBotInfo('type') != 'slack':
        raise RuntimeError('ERROR: This function/feature is only working with slack bots.')
    else:
        for val in find(botwayConfigData, 'botway'):
            return val['bots'][getBotInfo('name')]['signing_secret']



from setuptools import setup
import re

version = ""
with open("botway/__init__.py") as f:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', f.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError("version is not set")

readme = ""
with open("README.md") as f:
    readme = f.read()

setup(
    name="botway.py",
    author="abdfnx",
    url="https://github.com/abdfnx/botway",
    project_urls={
        "Issues": "https://github.com/abdfnx/botway/issues",
    },
    version=version,
    packages=["botway"],
    license="MIT",
    description="Python client package for Botway.",
    long_description=readme,
    long_description_content_type="text/markdown",
    include_package_data=True,
    python_requires=">=3.6.0",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: MIT License",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Internet",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Utilities",
    ]
)
